@@ -19,9 +19,9 @@
 # limitations under the License.
 
 
-__version__ = "0.0.8"
+__version__ = "0.0.14"
 
 __author__ = "Tradologics, Inc."
 
-from . import helpers, requests
-__all__ = ['helpers', 'requests']
+from . import server, helpers, requests
+__all__ = ['helpers', 'server', 'requests', "__version__"]
