@@ -21,7 +21,7 @@
 from .backtest import Backtest
 import requests as _requests
 
-_BASE_URL = "https://api.tradologics.com/beta"
+_BASE_URL = "https://api.tradologics.com/v1"
 _TOKEN = None
 _DEFAULT_TIMEOUT = 5
 _SOCKET_URL = "tcp://0.0.0.0:3003"
@@ -69,7 +69,7 @@ def _process_request(method, url, **kwargs):
     if _IS_BACKTEST:
         return _BACKTEST.call_eroc_method(method, url, **kwargs)
     else:
-        url = f"{_BASE_URL}/{url.strip('/')}"
+        url = "{}/{}".format(_BASE_URL, url.strip('/'))
         return _requests.request(method, url, **kwargs)
 
 
